from setuptools import setup


setup(
    name='retry',
    version='0.7.0',
    description='retry decorator',
    long_description=open('README.rst').read(),
    url='https://github.com/invl/retry',
    packages=['retry'],
    license='Apache License 2.0',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        "Programming Language :: Python :: Implementation :: PyPy",
    ]
)
